netapp_ontap.models.fc_port_transceiver API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.fc_port_transceiver`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class FcPortTransceiverSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the FcPortTransceiver object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `capabilities: List[Size] GET`

    The speeds of which the transceiver is capable in gigabits per second.

  `form_factor: str GET`

    The form factor of the transceiver. Possible values are: - sfp - Small Form Factor - Pluggable - sff - Small Form Factor - unknown - Unknown

    Valid choices:

    - sfp
    - sff
    - unknown
  `manufacturer: str GET`

    The manufacturer of the transceiver.

    Example: Acme, Inc.

  `part_number: str GET`

    The part number of the transceiver.